@@ -48,12 +48,11 @@ def add_alarm_status(
         print(new_alarm_status)
     """
     alarm_status_input = AddAlarmStatusInput(name=name)
-    if name == str:
+    if alarm_status_input.name is not str:
+        print ("the input must be a text, example name=\"new name\"")
+    else:
         result = addAlarmStatus.execute(client, input=alarm_status_input)
         return alarmStatus(name=result.name, id=result.id)
-    else:
-        print ("the input must be a text, example name=\"new name\"")
-
 
 
 def edit_alarm_status(
